@@ -4,27 +4,34 @@ import time
 from typing import Dict, List, Optional, Tuple, Union
 
 import torch
-from speechbrain.inference.enhancement import SpectralMaskEnhancement as enhance_model
-from speechbrain.inference.separation import SepformerSeparation as separator
 
 from senselab.audio.data_structures import Audio
 from senselab.audio.tasks.preprocessing import concatenate_audios, evenly_segment_audios
 from senselab.utils.data_structures import DeviceType, SpeechBrainModel, _select_device_and_dtype
 from senselab.utils.data_structures.logging import logger
 
+try:
+    from speechbrain.inference.enhancement import SpectralMaskEnhancement as enhance_model
+    from speechbrain.inference.separation import SepformerSeparation as separator
+
+    SPEECHBRAIN_AVAILABLE = True
+except ModuleNotFoundError:
+    SPEECHBRAIN_AVAILABLE = False
+
 
 class SpeechBrainEnhancer:
     """A factory for managing SpeechBrain enhancement pipelines."""
 
     MAX_DURATION_SECONDS = 60  # Maximum duration per segment in seconds
-    _models: Dict[str, Union[separator, enhance_model]] = {}
+    MIN_LENGTH = 16  # kernel size for speechbrain/sepformer-wham16k-enhancement
+    _models: Dict[str, Union["separator", "enhance_model"]] = {}
 
     @classmethod
     def _get_speechbrain_model(
         cls,
         model: SpeechBrainModel,
         device: Optional[DeviceType] = None,
-    ) -> Tuple[separator, DeviceType, torch.dtype]:
+    ) -> Tuple["separator", DeviceType, torch.dtype]:
         """Get or create a SpeechBrain enhancement model.
 
         Args:
@@ -37,6 +44,12 @@ class SpeechBrainEnhancer:
             device: The device used for the model.
             dtype: The dtype used for the model.
         """
+        if not SPEECHBRAIN_AVAILABLE:
+            raise ModuleNotFoundError(
+                "`speechbrain` is not installed. "
+                "Please install senselab audio dependencies using `pip install senselab['audio']`."
+            )
+
         device, dtype = _select_device_and_dtype(
             user_preference=device, compatible_devices=[DeviceType.CUDA, DeviceType.CPU]
         )
@@ -73,6 +86,12 @@ class SpeechBrainEnhancer:
         Returns:
             List[Audio]: The list of enhanced audio objects.
         """
+        if not SPEECHBRAIN_AVAILABLE:
+            raise ModuleNotFoundError(
+                "`speechbrain` is not installed. "
+                "Please install senselab audio dependencies using `pip install senselab['audio']`."
+            )
+
         if model is None:
             model = SpeechBrainModel(path_or_uri="speechbrain/sepformer-wham16k-enhancement", revision="main")
 
@@ -105,16 +124,21 @@ class SpeechBrainEnhancer:
             enhanced_segments = []
 
             for segment in segments:
-                if isinstance(enhancer, enhance_model):
-                    enhanced_waveform = enhancer.enhance_batch(segment.waveform, lengths=torch.tensor([1.0]))
+                if segment.waveform.shape[-1] < cls.MIN_LENGTH:
+                    print(f"Skipping segment with length {segment.waveform.shape[-1]}")
+                    # Append it as it is
+                    enhanced_segments.append(segment)
                 else:
-                    enhanced_waveform = enhancer.separate_batch(segment.waveform)
+                    if isinstance(enhancer, enhance_model):
+                        enhanced_waveform = enhancer.enhance_batch(segment.waveform, lengths=torch.tensor([1.0]))
+                    else:
+                        enhanced_waveform = enhancer.separate_batch(segment.waveform)
 
-                enhanced_segments.append(
-                    Audio(waveform=enhanced_waveform.reshape(1, -1), sampling_rate=segment.sampling_rate)
-                )
-                # TODO: decide what to do with metadata
+                    enhanced_segments.append(
+                        Audio(waveform=enhanced_waveform.reshape(1, -1), sampling_rate=segment.sampling_rate)
+                    )
 
+            # TODO: decide what to do with metadata
             enhanced_audio = concatenate_audios(enhanced_segments)
             enhanced_audio.metadata = audio.metadata
             enhanced_audios.append(enhanced_audio)
